<!doctype html> <!-- Important: must specify -->
<html>
  <head>
    <title>{{TITLE}}</title>
    <meta charset="utf-8"> <!-- Important: rapi-doc uses utf8 charecters -->
    <script type="module" src="https://unpkg.com/rapidoc/dist/rapidoc-min.js"></script>
  </head>
  <body>
    <rapi-doc
      spec-url = "{{OPENAPI_URL}}"
      render-style = "read"
      show-header = 'false'
    > </rapi-doc>
  </body>
</html>